@@ -1,10 +1,8 @@
 # enumerate.rb
 
-$:.unshift "../../../build/bindings/ruby"
-$:.unshift "../.libs"
-
 require 'test/unit'
 require 'rexml/document'
+require File.join(File.dirname(__FILE__),'_loadpath')
 require 'openwsman'
 require '_client'
 
@@ -19,7 +17,7 @@ class WsmanTest < Test::Unit::TestCase
     result = client.pull( options, nil, uri, context )
     assert result
 
-    doc = REXML::Document.new result.to_s
+    doc = REXML::Document.new result.to_xml
     assert doc
 #    doc.write( $stdout, 0 )
   end
