@@ -40,7 +40,6 @@
 extern "C" {
 #endif				/* __cplusplus */
 
-#include "u/libu.h"
 #include "wsman-xml-api.h"
 #include "wsman-names.h"
 #include "wsman-types.h"
@@ -106,6 +105,7 @@ typedef enum {
 		// accepted and we failed to login
 
 		WS_LASTERR_BAD_CRL_FILE, //bad CRL file provided (Format, Path or permission)
+		WS_LASTERR_CURL_BAD_FUNCTION_ARG, // bad function arg calling curl
 		WS_LASTERR_LAST	// never use!
 	} WS_LASTERR_Code;
 
@@ -159,7 +159,9 @@ typedef enum {
 #define FLAG_ENUMERATION_ENUM_OBJ_AND_EPR    0x0008
 #define FLAG_DUMP_REQUEST                    0x0010
 #define FLAG_IncludeSubClassProperties       0x0020
+#define FLAG_INCLUDESUBCLASSPROPERTIES       FLAG_IncludeSubClassProperties
 #define FLAG_ExcludeSubClassProperties       0x0040
+#define FLAG_EXCLUDESUBCLASSPROPERTIES       FLAG_ExcludeSubClassProperties
 #define FLAG_POLYMORPHISM_NONE               0x0080
 #define FLAG_MUND_MAX_ESIZE                  0x0100
 #define FLAG_MUND_LOCALE                     0x0200
@@ -190,6 +192,7 @@ typedef enum {
 		unsigned int timeout;
 		unsigned int max_envelope_size;
 		unsigned int max_elements;
+		hash_t *options; /* for WSM_OPTION_SET */
 	} client_opt_t;
 
 
@@ -743,6 +746,8 @@ typedef enum {
 	void wsmc_set_action_option(client_opt_t * options,
 				     unsigned int);
 
+	unsigned int wsmc_get_action_option(client_opt_t * options);
+
 	void wsmc_clear_action_option(client_opt_t * options,
 				     unsigned int);
 
@@ -751,12 +756,21 @@ typedef enum {
 
 	void wsmc_set_filter(filter_t *filter, client_opt_t * options);
 
+        void wsmc_add_option(client_opt_t * options,
+			     const char *key, const char *value);
+
 	void wsmc_add_selector(client_opt_t * options,
 				       const char *key, const char *value);
 
 	void wsmc_add_property(client_opt_t * options,
 				       const char *key, const char *value);
 
+        void wsmc_set_cim_ns(const char *delivery_uri, client_opt_t * options);
+  
+        void wsmc_set_fragment(const char *fragment, client_opt_t * options);
+
+        void wsmc_set_reference(const char *reference, client_opt_t * options);
+
 	/* Misc */
 
 	/* Place holder */
