@@ -38,7 +38,8 @@
 #ifndef WSMAN_SOAP_H_
 #define WSMAN_SOAP_H_
 
-#include "u/libu.h"
+#include "u/hash.h"
+#include "u/list.h"
 #include "wsman-faults.h"
 #include "wsman-soap-message.h"
 #include "wsman-xml-api.h"
@@ -223,7 +224,9 @@ typedef int     (*WsEndPointPut) (WsContextH, void *, void **, WsmanStatus *, vo
 
 typedef void   *(*WsEndPointGet) (WsContextH, WsmanStatus *, void *);
 
-#define WSE_NOTIFICATION_DRAOPEVENTS 1
+/* return values from wse_send_notification() */
+#define WSE_NOTIFICATION_DROPEVENTS 1
+#define WSE_NOTIFICATION_DRAOPEVENTS WSE_NOTIFICATION_DROPEVENTS /* sic! */
 #define WSE_NOTIFICATION_HEARTBEAT 2
 #define WSE_NOTIFICATION_NOACK 3
 #define WSE_NOTIFICATION_EVENTS_PENDING 4
@@ -246,9 +249,9 @@ typedef int (*WsEndPointSubscriptionCancel) (WsEventThreadContextH);
 #define WSMAN_ENUMINFO_REF          	  0x040000
 #define WSMAN_ENUMINFO_CQL          	  0x080000
 #define WSMAN_ENUMINFO_WQL          	  0x100000
-#define WSMAN_ENUMINFO_SELECTOR		0x200000
-#define WSMAN_ENUMINFO_CIM_CONTEXT_CLEANUP	0x400000
-
+#define WSMAN_ENUMINFO_SELECTOR		  0x200000
+#define WSMAN_ENUMINFO_CIM_CONTEXT_CLEANUP 0x400000
+#define WSMAN_ENUMINFO_XPATH              0x800000
 
 struct __WsEnumerateInfo {
 	unsigned long flags;
@@ -472,6 +475,9 @@ wsman_generate_fault(WsXmlDocH inDoc,
 		     WsmanFaultCodeType faultCode,
 		     WsmanFaultDetailType faultDetail,
 		     char *fault_msg);
+void
+wsman_get_fault_status_from_doc(WsXmlDocH doc,WsmanStatus* status) ;
+
 void
 wsman_generate_fault_buffer( WsXmlDocH inDoc,
 			     const char *encoding,
