@@ -45,18 +45,18 @@
 #include <unistd.h>
 #endif
 
+#include "u/libu.h"
 #include "wsman-client-transport.h"
 #include "wsman-soap.h"
 #include "wsman-client.h"
-#include "u/libu.h"
 
 static char *auth_methods[] = {
-	"noauth",
-	"basic",
-	"digest",
-	"pass",
-	"ntlm",
-	"gss",
+  _WS_NO_AUTH,
+  _WS_BASIC_AUTH,
+  _WS_DIGEST_AUTH,
+  _WS_PASS_AUTH,
+  _WS_NTLM_AUTH,
+  _WS_GSSNEGOTIATE_AUTH,
 	NULL,
 };
 
@@ -70,6 +70,7 @@ static long long transfer_time = 0;
 
 int wsman_send_request(WsManClient * cl, WsXmlDocH request)
 {
+        int ret = 0;
 #ifdef BENCHMARK
 	struct timeval tv0, tv1;
 	long long t0, t1;
@@ -86,7 +87,10 @@ int wsman_send_request(WsManClient * cl, WsXmlDocH request)
 #endif
 
 	wsmc_handler(cl, request, NULL);
-
+        if (cl->last_error != WS_LASTERR_OK) {
+          warning("Couldn't send request to client: %s\n", cl->fault_string);
+          ret = 1;
+        }
 #ifdef BENCHMARK
 	gettimeofday(&tv1, NULL);
 	t0 = tv0.tv_sec * 10000000 + tv0.tv_usec;
@@ -94,7 +98,7 @@ int wsman_send_request(WsManClient * cl, WsXmlDocH request)
 	transfer_time += t1 - t0;
 #endif
 	wsmc_unlock(cl);
-	return 0;
+	return ret;
 }
 
 #ifdef BENCHMARK
@@ -107,7 +111,7 @@ long long get_transfer_time()
 #endif
 
 
-char *wsmc_transport_get_auth_name(wsman_auth_type_t auth)
+const char *wsmc_transport_get_auth_name(wsman_auth_type_t auth)
 {
 	switch (auth) {
 	case WS_NO_AUTH:
@@ -116,6 +120,8 @@ char *wsmc_transport_get_auth_name(wsman_auth_type_t auth)
 		return _WS_BASIC_AUTH;
 	case WS_DIGEST_AUTH:
 		return _WS_DIGEST_AUTH;
+	case WS_PASS_AUTH:
+		return _WS_PASS_AUTH;
 	case WS_NTLM_AUTH:
 		return _WS_NTLM_AUTH;
 	case WS_GSSNEGOTIATE_AUTH:
@@ -134,13 +140,14 @@ void wsmc_transport_set_auth_request_func(WsManClient * cl,
 
 void wsman_transport_set_agent(WsManClient * cl, const char *arg)
 {
+	u_free(cl->user_agent);
 	cl->user_agent = arg ? u_strdup( arg ) : NULL;
 }
 
 char *wsman_transport_get_agent(WsManClient * cl)
 {
 	if (cl->user_agent)
-		return cl->user_agent;
+		return u_strdup(cl->user_agent);
 	else
 		return DEFAULT_USER_AGENT;
 }
@@ -148,6 +155,7 @@ char *wsman_transport_get_agent(WsManClient * cl)
 
 void wsman_transport_set_proxy(WsManClient * cl, const char *arg)
 {
+	u_free(cl->proxy_data.proxy);
 	cl->proxy_data.proxy = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -156,22 +164,31 @@ char *wsman_transport_get_proxy(WsManClient *cl)
 	return cl->proxy_data.proxy ? u_strdup( cl->proxy_data.proxy ) : NULL;
 }
 
-void wsman_transport_set_userName(WsManClient * cl, char *arg)
+void wsman_transport_set_userName(WsManClient * cl, const char *arg)
 {
-	if(arg) {
-		cl->data.user = u_strdup(arg);
-	}
+	u_free(cl->data.user);
+	cl->data.user = arg ? u_strdup(arg) : NULL;
 }
 
-void wsman_transport_set_password(WsManClient * cl, char *arg)
+char *wsman_transport_get_userName(WsManClient * cl)
 {
-	if(arg) {
-		cl->data.pwd = u_strdup(arg);
-	}
+	return cl->data.user ? u_strdup(cl->data.user) : NULL;
+}
+
+void wsman_transport_set_password(WsManClient * cl, const char *arg)
+{
+	u_free(cl->data.pwd);
+	cl->data.pwd = arg ? u_strdup(arg) : NULL;
+}
+
+char *wsman_transport_get_password(WsManClient * cl)
+{
+	return cl->data.pwd ? u_strdup(cl->data.pwd) : NULL;
 }
 
 void wsman_transport_set_proxyauth(WsManClient * cl, const char *arg)
 {
+	u_free(cl->proxy_data.proxy_auth);
 	cl->proxy_data.proxy_auth = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -194,11 +211,12 @@ void wsman_transport_set_timeout(WsManClient * cl, unsigned long arg)
 
 char *wsman_transport_get_auth_method(WsManClient * cl)
 {
-	return cl->authentication.method;
+  return cl->authentication.method ? u_strdup(cl->authentication.method) : NULL;
 }
 
 void wsman_transport_set_auth_method(WsManClient * cl, const char *arg)
 {
+	u_free(cl->authentication.method);
 	cl->authentication.method = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -272,7 +290,7 @@ void wsman_transport_set_crlfile(WsManClient * cl, const char *arg)
 
 char *wsman_transport_get_crlfile(WsManClient *cl)
 {
-        return cl->authentication.crl_file; 
+  return cl->authentication.crl_file ? u_strdup(cl->authentication.crl_file) : NULL; 
 }
 #endif
 
@@ -280,6 +298,7 @@ char *wsman_transport_get_crlfile(WsManClient *cl)
 
 void wsman_transport_set_cainfo(WsManClient * cl, const char *arg)
 {
+	u_free(cl->authentication.cainfo);
 	cl->authentication.cainfo = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -348,12 +367,12 @@ void wsman_transport_set_certhumbprint(WsManClient *cl, const char *arg)
 
 char *wsman_transport_get_certhumbprint(WsManClient *cl)
 {
-
 	return raw2hexadecimal(cl->authentication.certificatethumbprint, 20);
 }
 
 void wsman_transport_set_capath(WsManClient *cl, const char *arg)
 {
+	u_free(cl->authentication.capath);
 	cl->authentication.capath = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -365,6 +384,7 @@ char *wsman_transport_get_capath(WsManClient *cl)
 
 void wsman_transport_set_caoid(WsManClient *cl, const char *arg)
 {
+	u_free(cl->authentication.caoid);
 	cl->authentication.caoid = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -386,19 +406,33 @@ BOOL wsman_transport_get_calocal(WsManClient *cl)
 }
 #endif
 
-void wsman_transport_set_proxy_username(WsManClient *cl, char *proxy_username )
+char *wsman_transport_get_proxy_username(WsManClient *cl)
 {
-        cl->proxy_data.proxy_username = proxy_username;
+  return cl->proxy_data.proxy_username ? u_strdup(cl->proxy_data.proxy_username) : NULL;
 }
-void wsman_transport_set_proxy_password(WsManClient *cl, char *proxy_password )
+
+void wsman_transport_set_proxy_username(WsManClient *cl, const char *proxy_username )
 {
-        cl->proxy_data.proxy_password = proxy_password;
+  u_free(cl->proxy_data.proxy_username);
+  cl->proxy_data.proxy_username = proxy_username ? u_strdup(proxy_username) : NULL;
+}
+
+char *wsman_transport_get_proxy_password(WsManClient *cl)
+{
+  return cl->proxy_data.proxy_password ? u_strdup(cl->proxy_data.proxy_password) : NULL;
+}
+
+void wsman_transport_set_proxy_password(WsManClient *cl, const char *proxy_password )
+{
+  u_free(cl->proxy_data.proxy_password);
+  cl->proxy_data.proxy_password = proxy_password ? u_strdup(proxy_password) : NULL;
 }
 
 
 
 void wsman_transport_set_cert(WsManClient * cl, const char *arg)
 {
+	u_free(cl->authentication.sslcert);
 	cl->authentication.sslcert = arg ? u_strdup( arg ) : NULL;
 }
 
@@ -410,6 +444,7 @@ char *wsman_transport_get_cert(WsManClient *cl)
 
 void wsman_transport_set_key(WsManClient *cl, const char *key)
 {
+	u_free(cl->authentication.sslkey);
 	cl->authentication.sslkey = key ? u_strdup( key ) : NULL;
 }
 
@@ -423,9 +458,9 @@ char *wsman_transport_get_last_error_string(WS_LASTERR_Code err)
 {
 	switch (err) {
 	case WS_LASTERR_OK:
-		return "Everithing OK";
+		return "Everything OK";
 	case WS_LASTERR_FAILED_INIT:
-		return "Trnasport initailization failed";
+		return "Transport initialization failed";
 	case WS_LASTERR_UNSUPPORTED_PROTOCOL:
 		return "Unsupported protocol";
 	case WS_LASTERR_URL_MALFORMAT:
@@ -449,7 +484,7 @@ char *wsman_transport_get_last_error_string(WS_LASTERR_Code err)
 	case WS_LASTERR_HTTP_POST_ERROR:
 		return "HTTP POST error";
 	case WS_LASTERR_BAD_DOWNLOAD_RESUME:
-		return "Couldn't resume download";
+		return "Could not resume download";
 	case WS_LASTERR_TOO_MANY_REDIRECTS:
 		return "Catch endless re-direct loop";
 	case WS_LASTERR_SSL_CONNECT_ERROR:
@@ -465,7 +500,7 @@ char *wsman_transport_get_last_error_string(WS_LASTERR_Code err)
 	case WS_LASTERR_SSL_CACERT:
 		return "Problem with the CA certificate";
 	case WS_LASTERR_SSL_ENGINE_INITFAILED:
-		return " failed to initialise SSL engine";
+		return "Failed to initialise SSL engine";
 	case WS_LASTERR_SEND_ERROR:
 		return "Failed sending network data";
 	case WS_LASTERR_RECV_ERROR:
@@ -474,6 +509,8 @@ char *wsman_transport_get_last_error_string(WS_LASTERR_Code err)
 		return "Unrecognized transfer encoding";
 	case WS_LASTERR_LOGIN_DENIED:
 		return "User, password or similar was not accepted";
+	case WS_LASTERR_CURL_BAD_FUNCTION_ARG:
+		return "Internal error: Wrong function argument in call to CURL";
 	default:
 		return "Unrecognized error";
 	}
