@@ -312,6 +312,7 @@ check_unsupported_features(op_t * op)
 
 	n = ws_xml_get_child(header, 0, XML_NS_ADDRESSING, WSA_FAULT_TO);
 	if (n != NULL) {
+		debug("wsa:FaultTo is not supported");
 		retVal = 1;
 		generate_op_fault(op, WSMAN_UNSUPPORTED_FEATURE,
 					WSMAN_DETAIL_ADDRESSING_MODE);
@@ -781,7 +782,13 @@ dispatch_inbound_call(SoapH soap, WsmanMessage * msg, void *opaqueData)
 	WsXmlDocH in_doc = wsman_build_inbound_envelope( msg);
 	SoapDispatchH dispatch = NULL;
 	debug("Inbound call...");
-
+#if 0
+        /* debug incoming message */
+        int size;
+        char *buf;
+        ws_xml_dump_memory_node_tree_enc( ws_xml_get_soap_body(in_doc), &buf, &size, "UTF-8" );  
+	debug(buf);
+#endif
 	if (wsman_fault_occured(msg)) {
 		error("document is null");
 		goto DONE;
@@ -914,6 +921,7 @@ SoapDispatchH wsman_dispatcher(WsContextH cntx, void *data, WsXmlDocH doc)
 #ifdef ENABLE_EVENTING_SUPPORT
 	WsXmlNodeH nodedoc = NULL;
 #endif
+  /* FIXME: resUriMatch set but not used */
 	int i, resUriMatch = 0;
 	char *ns = NULL;
 
