@@ -50,6 +50,7 @@
 #include <libxml/xpathInternals.h>
 
 
+#include "u/libu.h"
 #include "wsman-xml-api.h"
 #include "wsman-soap.h"
 #include "wsman-xml.h"
@@ -324,8 +325,7 @@ int xml_parser_node_set(WsXmlNodeH node, int what, const char *str)
 		break;
 
 	case XML_NS_URI:
-		if ((xmlNs =
-					(xmlNsPtr) xml_parser_ns_find(node, str, NULL, 1,
+		if ((xmlNs = (xmlNsPtr) xml_parser_ns_find(node, str, NULL, 1,
 						1)) != NULL) {
 			xmlNode->ns = xmlNs;
 			retVal = 0;
@@ -396,6 +396,9 @@ WsXmlNodeH xml_parser_node_get(WsXmlNodeH node, int which)
 	return (WsXmlNodeH) xmlNode;
 }
 
+/* check if namespace is defined (at document root)
+ * and evtl. (bAddAtRootIfNotFound!=0) add it to the root node
+ */
 
 WsXmlNsH
 xml_parser_ns_find(WsXmlNodeH node,
@@ -469,21 +472,33 @@ xml_parser_ns_add(WsXmlNodeH node, const char *uri, const char *prefix)
 {
 	xmlNsPtr xmlNs = NULL;
 	if (node && uri) {
-		if ((xmlNs =
-					(xmlNsPtr) xml_parser_ns_find(node, uri, NULL, 0,
-						0)) != NULL) {
+		if ((xmlNs = (xmlNsPtr) xml_parser_ns_find(node, uri, NULL, 0, 0)) != NULL) {
+                        /* namespace is known */
 			if (xmlNs->prefix != NULL) {
 				xmlFree((char *) xmlNs->prefix);
 				xmlNs->prefix = NULL;
 			}
-
 			if (prefix != NULL) {
 				xmlNs->prefix = xmlStrdup(BAD_CAST prefix);
 			}
 		} else {
-			xmlNs =
-				xmlNewNs((xmlNodePtr) node, BAD_CAST uri,
-						BAD_CAST prefix);
+                        /* create new namespace entry */
+			xmlNs =	xmlNewNs((xmlNodePtr) node, BAD_CAST uri, BAD_CAST prefix);
+			/* since the 'xml:' name is supposed to be predefined, the above
+                         * function will return NULL when prefix == xml && uri == XML_XML_NAMESPACE.
+                         * Compensate for this here.
+                         */
+			if (xmlNs == NULL && strcmp(prefix,"xml") == 0
+                            && strcmp(uri, (const char *)XML_XML_NAMESPACE) == 0) {
+				xmlNs = (xmlNsPtr) u_zalloc(sizeof(xmlNs));
+				if (xmlNs == NULL) {
+					error("Couldn't create a new Namespace structure");	
+					return(NULL);
+				}
+				xmlNs->type = XML_LOCAL_NAMESPACE;
+				xmlNs->href = xmlStrdup((const xmlChar *)uri);
+				xmlNs->prefix = xmlStrdup((const xmlChar *)prefix);
+			}
 		}
 	}
 	return (WsXmlNsH) xmlNs;
@@ -802,7 +817,7 @@ void xml_parser_element_dump(FILE * f, WsXmlDocH doc, WsXmlNodeH node)
 {
 
 	xmlNodePtr n = (xmlNodePtr) node;
-	xmlDocPtr d = (xmlDocPtr) doc;
+	xmlDocPtr d = (xmlDocPtr) doc->parserDoc;
 	xmlElemDump(f, d, n);
 }
 
@@ -822,6 +837,14 @@ void xml_parser_doc_dump_memory(WsXmlDocH doc, char **buf, int *ptrSize)
 	return;
 }
 
+void xml_parser_doc_dump_memory_enc(WsXmlDocH doc, char **buf, int *ptrSize, const char *encoding)
+{
+
+	xmlDocPtr d = (xmlDocPtr) doc->parserDoc;
+        xmlDocDumpFormatMemoryEnc(d, (xmlChar **) buf, ptrSize, encoding?encoding:"UTF-8", 1);
+	return;
+}
+
 static void
 register_namespaces(xmlXPathContextPtr ctxt, WsXmlDocH doc,
 		WsXmlNodeH node)
