@@ -54,8 +54,11 @@ char *cim_host = "localhost";
 char *cim_port = DEFAULT_HTTP_CIMOM_PORT;
 char *server_port = "5985";
 char *cim_client_frontend = "XML";
+static int cim_ssl = 1; /* https connection to CIMOM */
+static int cim_verify = 1; /* verify ssl cert */
+static char *cim_trust_store = "/etc/ssl/certs"; /* path to cert trust store */
 int omit_schema_optional = 0;
-char *cim_indication_SourceNamespace = NULL;
+char *indication_profile_implementation_ns = NULL;
 
 SER_START_ITEMS(CimResource)
 SER_END_ITEMS(CimResource);
@@ -125,7 +128,7 @@ get_endpoints( void *self,
   WsDispatchInterfaceInfo *ifc = (WsDispatchInterfaceInfo *)data;
   ifc->flags = 0;
   ifc->actionUriBase = NULL;
-  ifc->version = PACKAGE_VERSION;
+  ifc->version = OPENWSMAN_PLUGIN_API_VERSION;
   ifc->config_id = "cim";
   ifc->vendor = "Openwsman Project";
   ifc->displayName = "CIM Resource";
@@ -159,8 +162,11 @@ void set_config( void *self, dictionary *config )
     cim_client_frontend = iniparser_getstring(config, "cim:cim_client_frontend", "XML");
     cim_port = iniparser_getstring(config, "cim:port", DEFAULT_HTTP_CIMOM_PORT);
     server_port = iniparser_getstring(config, "server:port", server_port);
+    cim_ssl = iniparser_getboolean(config, "cim:ssl", 0);
+    cim_trust_store = iniparser_getstring(config, "cim:trust_store", "/etc/ssl/certs");
+    cim_verify = iniparser_getboolean(config, "cim:verify_cert", 0);
     omit_schema_optional = iniparser_getboolean(config, "cim:omit_schema_optional", 0);
-    cim_indication_SourceNamespace = iniparser_getstr(config, "cim:indication_source_namespace");
+    indication_profile_implementation_ns = iniparser_getstring(config, "cim:indication_profile_implementation_ns", "root/interop");
     debug("vendor namespaces: %s", namespaces);
     if (namespaces) {
       hash_t * t = u_parse_query(namespaces);
@@ -206,7 +212,8 @@ get_cim_port()
     return cim_port;
 }
 
-char *get_server_port(void)
+char *
+get_server_port(void)
 {
    return server_port;
 }
@@ -221,8 +228,28 @@ get_cim_namespace()
 }
 
 char *
-get_cim_indication_SourceNamespace()
+get_indication_profile_implementation_ns()
 {
-	return cim_indication_SourceNamespace;
+    return indication_profile_implementation_ns;
 }
 
+/* use SSL to connect to CIMOM ? */
+int
+get_cim_ssl()
+{
+    return cim_ssl;
+}
+
+/* verify ssl cert ? */
+int
+get_cim_verify()
+{
+    return cim_verify;
+}
+
+/* path to cert trust store */
+char *
+get_cim_trust_store()
+{
+    return cim_trust_store;
+}
